@@ -1,9 +1,9 @@
-#include <string.h>
 #include "abc_000_macro.h"
 #include "abc_000_warning.h"
-#include "beastv2_header.h"
+#include <string.h>
 #include "abc_vec.h"   
 #include "abc_blas_lapack_lib.h" 
+#include "beastv2_header.h"
 static int DSVT(U08PTR good,I32 N,TKNOT_PTR KNOT,I64 nKnot,KNOT2BINVEC * info)
 {
 	I32 minSepDist=info->minSepDist;
@@ -22,9 +22,8 @@ static int OO(U08PTR good,I32 N,TKNOT_PTR KNOT,I64 nKnot,KNOT2BINVEC* info)
 	I32    nMissing=info->yInfo->nMissing;
 	I32PTR rowsMissing=info->yInfo->rowsMissing;
 	memset(good,1,N);
-	for (int i=0; i < nMissing; i++) {
-		I32 idx=rowsMissing[i];
-		good[idx - 1]=0;
+	for (int i=0; i < nMissing; i++) { 
+		good[rowsMissing[i]]=0;  
 	}
 	for (int i=0; i < nKnot; i++) {
 		I32 idx=KNOT[i];
