@@ -3,6 +3,7 @@
 #include <string.h>   
 #include "abc_ide_util.h"
 #include "abc_vec.h"
+#include "abc_date.h"
 #include "abc_mem.h"
 #include "beastv2_io.h"
 static void __RemoveFieldsGivenFlags_Trend(A(OPTIONS_PTR)  opt,FIELD_ITEM * fieldList,int nfields) {
@@ -145,60 +146,45 @@ static void __RemoveFieldsGivenFlags_Outlier(A(OPTIONS_PTR)  opt,FIELD_ITEM * fi
 	#undef _6
 	#undef _7
 }
-static void __ExtendDims_SwitchTimeDim_1D2D(FIELD_ITEM* fld,int outTimDim,int numTS) {
-	int ndim=fld->ndim;
-	if (ndim > 2||outTimDim >2||(numTS==1 && outTimDim!=1)) {
-		r_printf("__ExtendDims_SwitchTimeDim_1D2D:there must be something wrong!");
-	}
-	if        (outTimDim==1) {
-		fld->dims[ndim]=numTS;
-		fld->ndim++;
-	} else if (outTimDim==2) {
-		for (int i=ndim - 1; i >=0; i--) { fld->dims[i+1]=fld->dims[i]; }
-		fld->dims[0]=numTS;
-		fld->ndim++;;
-	}  
-}
-static void __ExtendDims_SwitchTimeDim_3D(FIELD_ITEM* fld,int outTimDim,int ROW,int COL) {
-	int ndim=fld->ndim;
-	if (ndim > 2||outTimDim >3) {
-		r_printf("__ExtendDims_SwitchTimeDim_1D2D:there must be something wrong!");
-	}
-	if  (outTimDim==1) {
-		fld->dims[ndim  ]=ROW;
-		fld->dims[ndim+1]=COL;
-		fld->ndim+=2;
-	} else if (outTimDim==3) {
-		for (int i=ndim - 1; i >=0; i--) {fld->dims[i+2]=fld->dims[i];}
-		fld->dims[0]=ROW;
-		fld->dims[1]=COL;
-		fld->ndim+=2;
-	} else if (outTimDim==2) {
-		for (int i=ndim - 1; i >=0; i--) {fld->dims[i+1 ]=fld->dims[i];}
-		fld->dims[0]=ROW;
-		fld->dims[ndim+1]=COL;
-		fld->ndim+=2;
-	}
-}
-static void   ExtendDims_SwitchTimeDim_AllFields(BEAST2_IO_PTR  io,FIELD_ITEM * fieldList,int nfields) {
-	if (io->ndim==1||io->ndim==2) {		
+static void   __AddSpatialDimension(int ROW,int COL,int whichOutDimIsTime,FIELD_ITEM * fieldList,int nfields) {
+  	if (whichOutDimIsTime==1) {
 		for (int i=0; i < nfields; i++) {
-			__ExtendDims_SwitchTimeDim_1D2D(fieldList+i,io->out.whichDimIsTime,io->numOfPixels);
+			FIELD_ITEM * fld=fieldList+i;
+			int          ndim=fld->ndim;
+			fld->dims[ndim]=ROW;
+			fld->dims[ndim+1]=COL;
+			fld->ndim+=2;
 		}
+		return;
 	}
-	else if (io->ndim==3) {		
-		int   ROW,COL;
-		switch (io->meta.whichDimIsTime) {
-			case 1:	ROW=io->dims[1],COL=io->dims[2]; break;
-			case 2:	ROW=io->dims[0],COL=io->dims[2]; break;
-			case 3:	ROW=io->dims[0],COL=io->dims[1]; break;
-		}
+	if (whichOutDimIsTime==2) {
 		for (int i=0; i < nfields; i++) {
-			__ExtendDims_SwitchTimeDim_3D(fieldList+i,io->out.whichDimIsTime,ROW,COL);
+			FIELD_ITEM * fld=fieldList+i;
+			int          ndim=fld->ndim;
+			for (int i=ndim - 1; i >=0; i--) { 
+				fld->dims[i+1]=fld->dims[i]; 
+			}
+			fld->dims[0]=ROW;
+			fld->dims[ndim+1]=COL;
+			fld->ndim+=2;
 		}
+		return;
+	}
+	if (whichOutDimIsTime==3) {
+		for (int i=0; i < nfields; i++) {
+			FIELD_ITEM * fld=fieldList+i;
+			int          ndim=fld->ndim;
+			for (int i=ndim - 1; i >=0; i--) {
+				fld->dims[i+2]=fld->dims[i]; 
+			}
+			fld->dims[0]=ROW;
+			fld->dims[1]=COL;
+			fld->ndim+=2;
+		}
+		return;
 	}
 }
-static  I32 __MR_ExtendFieldsToMultiVaraiteTS(FIELD_ITEM *flist,I32 N,I32 q) {
+static  I32  __MR_ExtendFieldsToMultiVaraiteTS(FIELD_ITEM *flist,I32 N,I32 q) {
 	if (q==1) 
 		return 0;
 	I32 nptr=0;
@@ -209,7 +195,7 @@ static  I32 __MR_ExtendFieldsToMultiVaraiteTS(FIELD_ITEM *flist,I32 N,I32 q) {
 		nptr_dummy++;
 		FIELD_ITEM qList[100]={ { {0,},},};
 		for (int j=0; j < q; j++) {
-			sprintf(qList[j].name,"Y%d",j+1); 	
+			snprintf(qList[j].name,63,"Y%d",j+1); 	
 			qList[j].extra=0;
 			qList[j].type=flist[i].type;
 			qList[j].ndim=flist[i].ndim;
@@ -229,27 +215,6 @@ static  I32 __MR_ExtendFieldsToMultiVaraiteTS(FIELD_ITEM *flist,I32 N,I32 q) {
 	 UNPROTECT(nptr_dummy); 
 	 return nptr;
 }
-static void __RemoveSingltonDims(FIELD_ITEM* flist,I32 nlist) {
-	for (int i=0; i < nlist; i++) {
-		if ( flist[i].ndim==1) continue;
-		int goodN=0;
-		int goodDims[4];
-		for (int j=0; j < flist[i].ndim; j++) {
-			if (flist[i].dims[j]!=1) {
-				goodDims[goodN++]=flist[i].dims[j];
-			}
-		}
-		if (goodN==0) {
-			flist[i].ndim=1;
-			flist[i].dims[0]=1;
-		} else {
-			flist[i].ndim=goodN;
-			for (int j=0; j < goodN; j++) {
-				flist[i].dims[j]=goodDims[j];
-			}
-		}
-	}
-}
 static void* __BEAST2_Output_AllocMEM_Trend(A(OPTIONS_PTR)  opt) {
 	const BEAST2_IO_PTR      io=&opt->io;
 	const BEAST2_RESULT_PTR  mat=io->out.result;
@@ -295,10 +260,10 @@ static void* __BEAST2_Output_AllocMEM_Trend(A(OPTIONS_PTR)  opt) {
 			 _q2(inc_cpCI,dec_cpCI,mxKnotNum,2),
 	};
 	I32 nfields=sizeof(fieldList)/sizeof(FIELD_ITEM);
-	ExtendDims_SwitchTimeDim_AllFields(io,fieldList,nfields);
+	__AddSpatialDimension(io->dims[io->rowdim-1],io->dims[io->coldim - 1],io->out.whichDimIsTime,fieldList,nfields);
 	__RemoveFieldsGivenFlags_Trend(opt,fieldList,nfields);
 	if (opt->extra.removeSingletonDims) {
-		__RemoveSingltonDims(fieldList,nfields);
+		RemoveSingltonDims(fieldList,nfields);
 	}
 	I32       nptr=__MR_ExtendFieldsToMultiVaraiteTS(fieldList,nfields,io->q); 
 	VOID_PTR  out=PROTECT(CreateStructVar(fieldList,nfields));
@@ -364,10 +329,10 @@ static void* __BEAST2_Output_AllocMEM_Season(A(OPTIONS_PTR)  opt)
 			_q2(pos_cpCI,neg_cpCI,mxKnotNum,2)				
 	};
 	I32 nfields=sizeof(fieldList)/sizeof(FIELD_ITEM);
-	ExtendDims_SwitchTimeDim_AllFields(io,fieldList,nfields);
+	__AddSpatialDimension(io->dims[io->rowdim - 1],io->dims[io->coldim - 1],io->out.whichDimIsTime,fieldList,nfields);
 	__RemoveFieldsGivenFlags_Season(opt,fieldList,nfields);
 	if (opt->extra.removeSingletonDims) {
-		__RemoveSingltonDims(fieldList,nfields);
+		RemoveSingltonDims(fieldList,nfields);
 	}
 	I32       nptr=__MR_ExtendFieldsToMultiVaraiteTS(fieldList,nfields,io->q); 
 	VOID_PTR  out=PROTECT(CreateStructVar(fieldList,nfields));
@@ -431,10 +396,10 @@ static void* __BEAST2_Output_AllocMEM_Outlier(A(OPTIONS_PTR)  opt)
 			_q2(pos_cpCI,neg_cpCI,mxKnotNum,2),
 	};
 	I32 nfields=sizeof(fieldList)/sizeof(FIELD_ITEM);
-	ExtendDims_SwitchTimeDim_AllFields(io,fieldList,nfields);
+	__AddSpatialDimension(io->dims[io->rowdim - 1],io->dims[io->coldim - 1],io->out.whichDimIsTime,fieldList,nfields);
 	__RemoveFieldsGivenFlags_Outlier(opt,fieldList,nfields);
 	if (opt->extra.removeSingletonDims) {
-		__RemoveSingltonDims(fieldList,nfields);
+		RemoveSingltonDims(fieldList,nfields);
 	}
 	I32       nptr=__MR_ExtendFieldsToMultiVaraiteTS(fieldList,nfields,io->q); 
 	VOID_PTR  out=PROTECT(CreateStructVar(fieldList,nfields));
@@ -459,8 +424,7 @@ static void* __BEAST2_Output_AllocMEM_Outlier(A(OPTIONS_PTR)  opt)
 	#undef _q6
 	#undef _q7
 }
-void* BEAST2_Output_AllocMEM(A(OPTIONS_PTR)  opt) 
-{	
+void* BEAST2_Output_AllocMEM(A(OPTIONS_PTR)  opt)  {	
 	if (opt->io.out.result) {
 		free(opt->io.out.result);
 	}
@@ -521,13 +485,13 @@ void* BEAST2_Output_AllocMEM(A(OPTIONS_PTR)  opt)
 	};
 	I32    nfields=sizeof(fieldList)/sizeof(FIELD_ITEM);
 	int sig2_index=6 - 1;
-	ExtendDims_SwitchTimeDim_AllFields(io,&fieldList[sig2_index],1L); 
-	ExtendDims_SwitchTimeDim_AllFields(io,&fieldList[1],1L);
+	__AddSpatialDimension(io->dims[io->rowdim - 1],io->dims[io->coldim - 1],io->out.whichDimIsTime,&fieldList[sig2_index],1L); 
+	__AddSpatialDimension(io->dims[io->rowdim - 1],io->dims[io->coldim - 1],io->out.whichDimIsTime,&fieldList[1],1L);
 	if (!opt->extra.dumpInputData) {  		 
 		RemoveField(fieldList,nfields,"data"); mat->data=NULL;
 	}
 	if (opt->extra.removeSingletonDims) {
-		__RemoveSingltonDims(fieldList,nfields);
+		RemoveSingltonDims(fieldList,nfields);
 	}
 	VOID_PTR  out;
 	I32       nptr1=__MR_ExtendFieldsToMultiVaraiteTS(fieldList,nfields,io->q);  nprt+=nptr1;
@@ -543,7 +507,7 @@ void* BEAST2_Output_AllocMEM(A(OPTIONS_PTR)  opt)
 	if (hasSeasonCmpnt && !hasDummyCmpnt) AddStringAttribute(out,"season_type","harmonic");
 	if (hasSeasonCmpnt &&  hasDummyCmpnt) AddStringAttribute(out,"season_type","dummy");
 	if (!hasSeasonCmpnt )                 AddStringAttribute(out,"season_type","none");
-	f32_seq(mat->time,io->meta.startTime,io->meta.deltaTime,N);
+     f32_seq(mat->time,io->meta.startTime,io->meta.deltaTime,N);
 	if (dtype==DATA_DOUBLE)  f32_to_f64_inplace(mat->time,N);
 	UNPROTECT(nprt);
 	return out;
